@@ -58,12 +58,7 @@ public class SingletonTransformersTestCase extends AbstractSubsystemTest {
 
     private static SingletonModel getModelVersion(ModelTestControllerVersion controllerVersion) {
         switch (controllerVersion) {
-            case EAP_7_0_0:
-                return SingletonModel.VERSION_1_0_0;
-            case EAP_7_1_0:
-            case EAP_7_2_0:
-                return SingletonModel.VERSION_2_0_0;
-            case EAP_7_3_0:
+            case EAP_7_4_0:
                 return SingletonModel.VERSION_3_0_0;
             default:
                 throw new IllegalArgumentException();
@@ -72,16 +67,15 @@ public class SingletonTransformersTestCase extends AbstractSubsystemTest {
 
     private static String[] getDependencies(ModelTestControllerVersion version) {
         switch (version) {
-            case EAP_7_0_0:
-            case EAP_7_1_0:
-            case EAP_7_2_0:
-            case EAP_7_3_0:
+            case EAP_7_4_0:
                 return new String[] {
                         formatEAP7SubsystemArtifact(version),
+                        formatArtifact("org.jboss.eap:wildfly-clustering-api:%s", version),
+                        formatArtifact("org.jboss.eap:wildfly-clustering-common:%s", version),
+                        formatArtifact("org.jboss.eap:wildfly-clustering-server:%s", version),
                         formatArtifact("org.jboss.eap:wildfly-clustering-service:%s", version),
                         formatArtifact("org.jboss.eap:wildfly-clustering-singleton-api:%s", version),
                         formatArtifact("org.jboss.eap:wildfly-clustering-spi:%s", version),
-                        formatArtifact("org.jboss.eap:wildfly-clustering-common:%s", version),
                 };
             default:
                 throw new IllegalArgumentException();
@@ -100,23 +94,8 @@ public class SingletonTransformersTestCase extends AbstractSubsystemTest {
     }
 
     @Test
-    public void testTransformerEAP700() throws Exception {
-        this.testTransformation(ModelTestControllerVersion.EAP_7_0_0);
-    }
-
-    @Test
-    public void testTransformerEAP710() throws Exception {
-        this.testTransformation(ModelTestControllerVersion.EAP_7_1_0);
-    }
-
-    @Test
-    public void testTransformerEAP720() throws Exception {
-        this.testTransformation(ModelTestControllerVersion.EAP_7_2_0);
-    }
-
-    @Test
-    public void testTransformerEAP730() throws Exception {
-        this.testTransformation(ModelTestControllerVersion.EAP_7_3_0);
+    public void testTransformerEAP740() throws Exception {
+        this.testTransformation(ModelTestControllerVersion.EAP_7_4_0);
     }
 
     private void testTransformation(final ModelTestControllerVersion controller) throws Exception {
@@ -129,23 +108,8 @@ public class SingletonTransformersTestCase extends AbstractSubsystemTest {
     }
 
     @Test
-    public void testRejectionsEAP700() throws Exception {
-        this.testRejections(ModelTestControllerVersion.EAP_7_0_0);
-    }
-
-    @Test
-    public void testRejectionsEAP710() throws Exception {
-        this.testRejections(ModelTestControllerVersion.EAP_7_1_0);
-    }
-
-    @Test
-    public void testRejectionsEAP720() throws Exception {
-        this.testRejections(ModelTestControllerVersion.EAP_7_2_0);
-    }
-
-    @Test
-    public void testRejectionsEAP730() throws Exception {
-        this.testRejections(ModelTestControllerVersion.EAP_7_3_0);
+    public void testRejectionsEAP740() throws Exception {
+        this.testRejections(ModelTestControllerVersion.EAP_7_4_0);
     }
 
     private void testRejections(final ModelTestControllerVersion controller) throws Exception {
